'use strict';

var Cookies = require('cookies');
var helpers = require('../helpers');

/**
 * Revokes any tokens currently attached to the request.
 *
 * @param {Object} req - The http request.
 * @param {Object} res - The http response.
 */
module.exports = function (req, res) {
  var cookies = new Cookies(req, res);

  var client = req.app.get('stormpathClient');
  var config = req.app.get('stormpathConfig');

  var jwtSigningKey = config.client.apiKey.secret;

  var accessTokenJwt = cookies.get(config.web.accessTokenCookie.name);
  var refreshTokenJwt = cookies.get(config.web.refreshTokenCookie.name);

  if (accessTokenJwt) {
    helpers.revokeToken.revokeAccessToken(client, accessTokenJwt, jwtSigningKey);
  }

  if (refreshTokenJwt) {
    helpers.revokeToken.revokeRefreshToken(client, refreshTokenJwt, jwtSigningKey);
  }
};
